@@ -86,7 +86,7 @@ int dodump = 0;
 int verbose = 0;
 int vverbose = 0;
 int leon = 1;
-double freq = 5E7;
+double freq = 0;
 int romres = 0;
 int comp = 1;
 int flash = 0;
@@ -175,7 +175,6 @@ int main (argc, argv)
     char cmd[512];
     char msg[128];
     int baud = 19200;
-    int dsubaud = 0;
     int dsubreak = 0;
     int i;
     unsigned int dsu_start = 0x90000000;
@@ -187,16 +186,14 @@ int main (argc, argv)
     int romcs = 1;
     int rombanks = 1;
     int ramsize = 0x200000;
-    int ramws = 0;
-    int ramrws = 0;
-    int ramwws = 0;
+    int ramrws = 3;
+    int ramwws = 3;
     int ramwidth = 32;
     int oramwidth = 32;
     int romwidth = 0;
     int rmw = 0;
-    int romws = 2;
-    int romrws = 2;
-    int romwws = 2;
+    int romrws = 15;
+    int romwws = 15;
     int stack[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
     int stat = 1;
     int bmsg = 1;
@@ -230,7 +227,6 @@ int main (argc, argv)
     struct mpirqe { int cpu, sel; } mpirqsel[16] = {{0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}, {0,0}};
     unsigned int mpirqselcnt = 0;
     unsigned int memcaddr = 0x80000000;
-    unsigned int dsuuart_addr = 0x80000700;
     unsigned int gptaddr = 0x80000300;
     unsigned int irqmpaddr = 0x80000200;
     int ecos = 0;
@@ -562,11 +558,6 @@ int main (argc, argv)
 		  {
 		      ecos = 1;
 		  }
-		else if (strcmp (argv[stat], "-dsubaud") == 0)
-		  {
-		      if ((stat + 1) < argc)
-			  dsubaud = VAL (argv[++stat]);
-		  }
 		else if (strcmp (argv[stat], "-rstaddr") == 0)
 		  {
 		      if ((stat + 1) < argc)
@@ -626,11 +617,6 @@ int main (argc, argv)
 		      if ((stat + 1) < argc)
 			  irqmpaddr = VAL (argv[++stat]);
 		  }
-		else if (strcmp (argv[stat], "-duart") == 0)
-		  {
-		      if ((stat + 1) < argc)
-			  dsuuart_addr = VAL (argv[++stat]);
-		  }
 		else if (strcmp (argv[stat], "-col") == 0)
 		  {
 		      if ((stat + 1) < argc)
@@ -750,6 +736,8 @@ int main (argc, argv)
 		  {
 		      if ((stat + 1) < argc)
 			{
+			    int romws;
+
 			    romws = (VAL (argv[++stat])) & 0xf;
 			    romrws = romwws = romws;
 			}
@@ -898,6 +886,8 @@ int main (argc, argv)
 		  {
 		      if ((stat + 1) < argc)
 			{
+			    int ramws;
+
 			    ramws = (VAL (argv[++stat])) & 0x3;
 			    ramrws = ramwws = ramws;
 			}
@@ -1005,6 +995,11 @@ int main (argc, argv)
         exit(1);
     }
 
+    if (freq < 1) {
+        fprintf(stderr, "ERROR: Missing mandatory option -freq <mhz>\n");
+        exit(1);
+    }
+
 	/* Setup defualt UART address */
 	if (!uartnr) {
 		if (leon2) {
@@ -1087,7 +1082,7 @@ int main (argc, argv)
       {
           fprintf (dumpfile, "\n\t.text\n");
 	  fprintf (dumpfile,
-		   "\n\t.global _memcfg1, _memcfg2, _memcfg3, _sdmemcfg1,  _memcaddr, _uart, _dsuuart, _scaler,  _uaddr, _gptaddr, _irqmpaddr, _dsuuart_addr, _iserc32, _agga4, _doedac, _doft, _clean_ram0, _clean_ram0_size, _clean_ram1, _clean_ram1_size, _ddrspa_cfg1, _ddr2spa_cfg1, _ddr2spa_cfg3, _ddr2spa_cfg4, _dsustart, _dsutrace, _nopnp, _isddr, _pnp, _mp, _sdctrl_sdcfg, _spimcfg, _dsuctrl \n");
+		   "\n\t.global _memcfg1, _memcfg2, _memcfg3, _sdmemcfg1,  _memcaddr, _uart, _scaler,  _uaddr, _gptaddr, _irqmpaddr, _iserc32, _agga4, _doedac, _doft, _clean_ram0, _clean_ram0_size, _clean_ram1, _clean_ram1_size, _ddrspa_cfg1, _ddr2spa_cfg1, _ddr2spa_cfg3, _ddr2spa_cfg4, _dsustart, _dsutrace, _nopnp, _isddr, _pnp, _mp, _sdctrl_sdcfg, _spimcfg, _dsuctrl \n");
 	  fprintf (dumpfile,"\n\t.global _uartnr, _sparcleon0, _mpstart, freqkhz\n");
 	  fprintf (dumpfile,"\n\t.global _mpirqsel0, _mpirqsel1, ftsdctrl64_pwr, ftsdctrl64_cfg, ftsdctrl64_edac, ftahbram_cfg\n");
       }
@@ -1549,13 +1544,6 @@ int main (argc, argv)
 	  fprintf (dumpfile, "_uartnr:\n");
 	  fprintf (dumpfile, "\t.word\t %d\n", uartnr);
 	  tmp = 0;
-	  if (dsubaud)
-	    {
-		tmp = (((10 * (int) freq) / (8 * dsubaud)) + 5) / 10 - 1;
-		dsubaud = freq / (8 * (tmp + 1));
-	    }
-	  fprintf (dumpfile, "_dsuuart:\n");
-	  fprintf (dumpfile, "\t.word\t%d\n", tmp);
 
 	  /* if ftmctrl.edac and ramwidth 8 then use upper 1/4 as bch */
     if (!stack[0]) {
@@ -1646,15 +1634,7 @@ int main (argc, argv)
 	    fprintf (dumpfile, "\t.word\t0x%08x\n", uaddr[0]);
 	  fprintf (dumpfile, "_uartnr:\n");
 	  fprintf (dumpfile, "\t.word\t %d\n", uartnr);
-	  tmp = 0;
-	  if (dsubaud)
-	    {
-		tmp = (((10 * (int) freq) / (8 * dsubaud)) + 5) / 10 - 1;
-		dsubaud = freq / (8 * (tmp + 1));
-	    }
-	  fprintf (dumpfile, "_dsuuart:\n");
-	  fprintf (dumpfile, "\t.word\t%d\n", tmp);
-	  
+
 	  tmp = 0;
 	  fprintf (dumpfile, "_memcfg3:\n");
 	  if (memcfg3_on)
@@ -1707,8 +1687,6 @@ int main (argc, argv)
     fprintf (dumpfile, "\t.word\t0x%x\n", gptaddr);
     fprintf (dumpfile, "_irqmpaddr:\n");
     fprintf (dumpfile, "\t.word\t0x%x\n", irqmpaddr);
-    fprintf (dumpfile, "_dsuuart_addr:\n");
-    fprintf (dumpfile, "\t.word\t0x%x\n", dsuuart_addr);
 
     sprintf (cmd, "  system clock   : %3.1f MHz\\n\\r", freq / 1E6);
     sprintf (msg, "  baud rate      : %d baud\\n\\r", baud);
@@ -2098,14 +2076,14 @@ int main (argc, argv)
 
 void usage (char *argv0)
 {
-	 printf("Usage: %s [options] input_files\n\n", argv0);
+	 printf("Usage: %s -freq <mhz> [options] input_files\n\n", argv0);
 
 	 puts("Mkprom General Options");
 	 puts("  -baud <baudrate>\tSet rate of UART A to baudrate. Default value is 19200.");
 	 puts("  -bdinit\t\tCall the functions bdinit1() and bdinit2() in file\n\t\t\tbdinit.o during startup. See manual.");
 //	 puts("\tThe user can optionally call two user-defined routines, bdinit1() and bdinit2(), during  the boot process. bdinit1() is called after the LEON registers have been initialized but before the memory has been cleared. bdinit2() is called after the memory has been initialized but before the application is loaded. Note that when bdinit1() is called, the stack has not been setup meaning that bdinit1() must be a leaf routine and not allocate any stack space (no local variables). When -bdinit is used, a file called bdinit.o must exist in the current directory, containing the two routines.");
 	 puts("  -dump\t\t\tThe intermediate assembly code with the compressed\n\t\t\tapplication and the LEON register values is put in dump.s\n\t\t\t(only for debugging of mkprom).");
-	 puts("  -freq <system_clock>\tDefines the system clock in MHz. This value is used to\n\t\t\tcalculate the divider value for the baud rate generator\n\t\t\tand the real-time clock. Default is 50 for LEON.");
+	 puts("  -freq <mhz>\t\tDefines the system clock in MHz. This value is used to\n\t\t\tcalculate the divider value for the baud rate generator\n\t\t\tand timers.");
 	 puts("  -noinit\t\tSuppress all code which initializes on-chip peripherals\n\t\t\tsuch as uarts, timers and memory controllers. This option\n\t\t\trequires -bdinit to add custom initialisation code,\n\t\t\tor the boot process will fail.");
 	 puts("  -nomsg\t\tSuppress the boot message.");
 	 puts("  -romres\t\tCreate ROM resident image.");
@@ -2126,12 +2104,10 @@ void usage (char *argv0)
 	 puts("  -nosram\t\tDisables the static RAM and maps SDRAM at\n\t\t\taddress 0x40000000.");
 	 puts("  -ramsize <size>\tDefines the total available RAM. Used to initialize\n\t\t\tmemory configuration register(s) and stack calculation.\n\t\t\tThe default value is 2048 (2 Mbyte).");
 	 puts("  -ramcs <chip_selects>\tSet the number of ram banks to chip_selects.\n\t\t\tDefault is 1.");
-	 puts("  -ramws <ws>\t\tSet the number of waitstates during ram reads and writes\n\t\t\tto ws. Default is 0.");
-	 puts("  -ramrws <ws>\t\tSet the number of waitstates during ram reads to ws.\n\t\t\tDefault is 0.");
-	 puts("  -ramwws <ws>\t\tSet the number of waitstates during ram writes to ws.\n\t\t\tDefault is 0.");
-	 puts("  -romws <ws>\t\tSet the number of rom waitstates during read and write\n\t\t\tto ws. Default is 2.");
-	 puts("  -romrws <ws>\t\tSet the number of rom waitstates during read to ws.\n\t\t\tDefault is 2.");
-	 puts("  -romwws <ws>\t\tSet the number of rom waitstates during write to ws.\n\t\t\tDefault is 2.");
+	 puts("  -romws <ws>\t\tSet the PROM read and write wait states parameter. Default is 15.");
+	 puts("  -ramws <ws>\t\tSet the SRAM read and write wait states parameter. Default is 3.");
+	 puts("  -ramrws <ws>\t\tSet the SRAM  read wait states parameter. Default is 3.");
+	 puts("  -ramwws <ws>\t\tSet the SRAM write wait states parameter. Default is 3.");
 	 puts("  -ramwidth <width>\tSet the data bus width to 8, 16 or 32-bits, default is 32.\n\t\t\tThe prom width is set through the PIO[1:0] ports.");
 	 puts("  -rmw\t\t\tPerform read-modify-write cycles during byte\n\t\t\tand halfword writes.");
 	 puts("  -sdram <size>\t\tThe amount of attached SDRAM in Mbyte. 0 by default");
